==> tabular-data-expression-widget-1.4.0-20141211.113009-22-servicearchive.tar.gz: org/gcube/portlets/user/td/expressionwidget/shared/model/composite/comparable/C_GreaterOrEquals.java <==
package org.gcube.portlets.user.td.expressionwidget.shared.model.composite.comparable;

import org.gcube.portlets.user.td.expressionwidget.shared.model.C_OperatorType;
import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_Expression;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class C_GreaterOrEquals extends C_Expression {
	private static final long serialVersionUID = -5441076239992740424L;

	protected String id = "GreaterOrEquals";
	protected C_Expression leftArgument;
	protected C_Expression rightArgument;

	public C_GreaterOrEquals(){
		
	}
	
	public C_GreaterOrEquals(C_Expression leftArgument,
			C_Expression rightArgument) {
		this.leftArgument = leftArgument;
		this.rightArgument = rightArgument;
	}

	public C_OperatorType getOperator() {
		return C_OperatorType.GREATER_OR_EQUALS;
	}

	public String getReturnedDataType() {
		return "Boolean";
	}
	
	@Override
	public String getId() {
		return id;
	}

	public C_Expression getLeftArgument() {
		return leftArgument;
	}

	public void setLeftArgument(C_Expression leftArgument) {
		this.leftArgument = leftArgument;
	}

	public C_Expression getRightArgument() {
		return rightArgument;
	}

	public void setRightArgument(C_Expression rightArgument) {
		this.rightArgument = rightArgument;
	}

	@Override
	public String toString() {
		return "GreaterOrEquals [id=" + id + ", leftArgument=" + leftArgument
				+ ", rightArgument=" + rightArgument + "]";
	}

}

==> tabular-data-expression-widget-1.6.0-20150623.082705-169-servicearchive.tar.gz: org/gcube/portlets/user/td/expressionwidget/shared/model/composite/comparable/C_GreaterOrEquals.java <==
package org.gcube.portlets.user.td.expressionwidget.shared.model.composite.comparable;

import org.gcube.portlets.user.td.expressionwidget.shared.model.C_OperatorType;
import org.gcube.portlets.user.td.widgetcommonevent.shared.expression.C_Expression;

/**
 * 
 * @author "Giancarlo Panichi" <a
 *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
 * 
 */
public class C_GreaterOrEquals extends C_Expression {
	private static final long serialVersionUID = -5441076239992740424L;

	protected String id = "GreaterOrEquals";
	protected C_Expression leftArgument;
	protected C_Expression rightArgument;

	public C_GreaterOrEquals() {

	}

	public C_GreaterOrEquals(C_Expression leftArgument,
			C_Expression rightArgument) {
		this.leftArgument = leftArgument;
		this.rightArgument = rightArgument;
		if (leftArgument != null && rightArgument != null) {
			this.readableExpression = "GreaterOrEquals("
					+ leftArgument.getReadableExpression() + ","
					+ rightArgument.getReadableExpression() + ")";
		}
	}

	public C_OperatorType getOperator() {
		return C_OperatorType.GREATER_OR_EQUALS;
	}

	public String getReturnedDataType() {
		return "Boolean";
	}

	@Override
	public String getId() {
		return id;
	}

	public C_Expression getLeftArgument() {
		return leftArgument;
	}

	public void setLeftArgument(C_Expression leftArgument) {
		this.leftArgument = leftArgument;
	}

	public C_Expression getRightArgument() {
		return rightArgument;
	}

	public void setRightArgument(C_Expression rightArgument) {
		this.rightArgument = rightArgument;
	}

	@Override
	public String toString() {
		return "GreaterOrEquals [id=" + id + ", leftArgument=" + leftArgument
				+ ", rightArgument=" + rightArgument + "]";
	}

}
